]> git.cameronkatri.com Git - mandoc.git/blobdiff - libroff.h
Remove delims from struct tbl (not used anywhere and never will be).
[mandoc.git] / libroff.h
index f3c7fed1d49475c859a8c6ae541ea0dd4717c8e2..b4e043a7ac4107af413d65c56230967a96529ece 100644 (file)
--- a/libroff.h
+++ b/libroff.h
@@ -1,4 +1,4 @@
-/*     $Id: libroff.h,v 1.2 2010/12/28 13:46:07 kristaps Exp $ */
+/*     $Id: libroff.h,v 1.16 2011/01/04 15:02:00 kristaps Exp $ */
 /*
  * Copyright (c) 2009, 2010 Kristaps Dzonsons <kristaps@bsd.lv>
  *
 
 __BEGIN_DECLS
 
-enum   tbl_tok {
-       TBL_TOK_OPENPAREN = 0,
-       TBL_TOK_CLOSEPAREN,
-       TBL_TOK_COMMA,
-       TBL_TOK_SEMICOLON,
-       TBL_TOK_PERIOD,
-       TBL_TOK_SPACE,
-       TBL_TOK_TAB,
-       TBL_TOK_NIL,
-       TBL_TOK__MAX
-};
-
 enum   tbl_part {
        TBL_PART_OPTS, /* in options (first line) */
        TBL_PART_LAYOUT, /* describing layout */
-       TBL_PART_DATA  /* creating data rows */
+       TBL_PART_DATA, /* creating data rows */
+       TBL_PART_CDATA /* continue previous row */
 };
 
-struct tbl {
+struct tbl_node {
+       mandocmsg         msg; /* status messages */
+       void             *data; /* privdata for messages */
+       int               pos; /* invocation column */
+       int               line; /* invocation line */
        enum tbl_part     part;
-       char              buf[BUFSIZ];
-       char              tab; /* cell-separator */
-       char              decimal; /* decimal point */
-       int               linesize;
-       char              delims[2];
-       int               opts;
-#define        TBL_OPT_CENTRE   (1 << 0)
-#define        TBL_OPT_EXPAND   (1 << 1)
-#define        TBL_OPT_BOX      (1 << 2)
-#define        TBL_OPT_DBOX     (1 << 3)
-#define        TBL_OPT_ALLBOX   (1 << 4)
-#define        TBL_OPT_NOKEEP   (1 << 5)
-#define        TBL_OPT_NOSPACE  (1 << 6)
+       struct tbl        opts;
+       struct tbl_row   *first_row;
+       struct tbl_row   *last_row;
+       struct tbl_span  *first_span;
+       struct tbl_span  *last_span;
+       struct tbl_head  *first_head;
+       struct tbl_head  *last_head;
+       struct tbl_node  *next;
 };
 
-struct tbl     *tbl_alloc(void);
-void            tbl_free(struct tbl *);
-void            tbl_reset(struct tbl *);
-enum rofferr    tbl_read(struct tbl *, int, const char *, int);
-enum tbl_tok    tbl_next(struct tbl *, const char *, int *);
+#define        TBL_MSG(tblp, type, line, col) \
+       (*(tblp)->msg)((type), (tblp)->data, (line), (col), NULL)
+
+struct tbl_node        *tbl_alloc(int, int, void *, mandocmsg);
+void            tbl_restart(int, int, struct tbl_node *);
+void            tbl_free(struct tbl_node *);
+void            tbl_reset(struct tbl_node *);
+enum rofferr    tbl_read(struct tbl_node *, int, const char *, int);
+int             tbl_option(struct tbl_node *, int, const char *);
+int             tbl_layout(struct tbl_node *, int, const char *);
+int             tbl_data(struct tbl_node *, int, const char *);
+int             tbl_cdata(struct tbl_node *, int, const char *);
+const struct tbl_span *tbl_span(const struct tbl_node *);
+void            tbl_end(struct tbl_node *);
 
 __END_DECLS